isIOSContext static method
Returns whether the effective style for context resolves to iOS.
Implementation
static bool isIOSContext(BuildContext context) {
return resolveStyle(context).isIOS;
}
Returns whether the effective style for context resolves to iOS.
static bool isIOSContext(BuildContext context) {
return resolveStyle(context).isIOS;
}