DraftModeValidationDependencyContext class abstract

Extended validation context that can optionally track dependencies.

Inheritance
Implementers

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

beginAttributeValidation(dynamic attribute) → void
Marks the start of validation for a concrete attribute.
endAttributeValidation(dynamic attribute) → void
Marks the end of validation for a concrete attribute.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
read<V>(dynamic attribute) → V?
Returns the current value for a related attribute, if available.
inherited
registerDependency(dynamic dependency) → void
Records that the current validation depends on dependency.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited