DraftModeValidationValueContext class abstract
Context used by reusable validation contracts to inspect related values without depending on a specific runtime like forms or repositories.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
read<
V> (dynamic attribute) → V? -
Returns the current value for a related
attribute, if available. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited