read<V> abstract method
V?
read<V>(
- dynamic attribute
Returns the current value for a related attribute, if available.
Implementation
V? read<V>(dynamic attribute);
Returns the current value for a related attribute, if available.
V? read<V>(dynamic attribute);