DraftModeValidationAfterOrEqual class

Raised when a value must be after or equal to a comparison date/time.

Inheritance

Constructors

DraftModeValidationAfterOrEqual(DateTime expected)
const

Properties

expected DateTime
Comparison value that the validated value must not precede.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolve(BuildContext context) String
Resolves this issue into user-facing text for the given context.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited