DraftModeValidationMaxLength class

Raised when a string exceeds the allowed length.

Inheritance

Constructors

DraftModeValidationMaxLength(int expected)
const

Properties

expected int
Maximum allowed character count.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolve(BuildContext context) String
Resolves this issue into user-facing text for the given context.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited