DraftModeEntityValidationException<TEntity> class

Exception raised when repository/storage validation fails.

Implemented types

Constructors

DraftModeEntityValidationException({required Type entityType, required String operation, required List<DraftModeEntityValidationFailure<TEntity>> failures})

Properties

entityType Type
Entity type being validated.
final
failures List<DraftModeEntityValidationFailure<TEntity>>
Concrete field failures found during validation.
final
hashCode int
The hash code for this object.
no setterinherited
operation String
Operation during which validation failed.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited