DraftModeEntityValidationFailure<TEntity> class
Validation failure produced when an entity violates one field contract.
Constructors
-
DraftModeEntityValidationFailure({required DraftModeEntityField<
TEntity, dynamic> field, required DraftModeValidationIssue issue}) -
const
Properties
-
field
→ DraftModeEntityField<
TEntity, dynamic> -
Field whose contract failed.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- issue → DraftModeValidationIssue
-
Concrete issue reported by field.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited