formatter library
Shared formatting helpers that are not specific to forms.
Classes
- DraftModeFormatterDateTime
-
Lightweight token-based formatter for rendering Duration values without
requiring the heavier
intldependency.
Shared formatting helpers that are not specific to forms.
intl dependency.