DraftModeFormDependencyContext class abstract
Extended validation context that tracks cross-field dependencies.
- Inheritance
-
- Object
- DraftModeValidationValueContext
- DraftModeFormValueContext
- DraftModeFormDependencyContext
- Implemented types
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
beginAttributeValidation(
dynamic attribute) → void -
Marks the start of validation for a concrete
attribute.inherited -
endAttributeValidation(
dynamic attribute) → void -
Marks the end of validation for a concrete
attribute.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
read<
V> (dynamic attribute) → V? -
Returns the current value for a related
attribute, if available.inherited -
registerDependency(
dynamic dependency) → void -
Records that the current validation depends on
dependency.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited