DraftModeFormDropDown<ItemType, ValueType> class

Inheritance

Constructors

DraftModeFormDropDown({Key? key, required List<ItemType> items, required DraftModeFormAttribute<ValueType> attribute, required ValueType valueOf(ItemType item), required DraftModeFormListItemBuilder<ItemType> itemBuilder, required String placeholder, bool readOnly = false, String? label, String? selectionTitle, ValueChanged<ValueType?>? onSaved})
const

Properties

attribute DraftModeFormAttribute<ValueType>
final
hashCode int
The hash code for this object.
no setterinherited
itemBuilder DraftModeFormListItemBuilder<ItemType>
final
items List<ItemType>
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
label String?
final
onSaved ValueChanged<ValueType?>?
final
placeholder String
final
readOnly bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectionTitle String?
final
valueOf → ValueType Function(ItemType item)
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<DraftModeFormDropDown<ItemType, ValueType>>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited