read<V> method
Returns the current value for a related attribute, if available.
Implementation
@override
V? read<V>(dynamic attribute) => controller.read<V>(attribute);
Returns the current value for a related attribute, if available.
@override
V? read<V>(dynamic attribute) => controller.read<V>(attribute);