validate method
Validates every FormField that is a descendant of this Form, and returns true if there are no errors.
The form will rebuild to report the results.
See also:
- validateGranularly, which also validates descendant FormFields, but instead returns a Set of fields with errors.
Implementation
@override
bool validate() {
_enableValidation = true;
FocusScope.of(context).unfocus();
return super.validate();
}