DraftModeFormNumberFormatter<T extends num> class

Locale-style numeric formatter used by typed form fields.

Inheritance
Implemented types
Implementers

Constructors

DraftModeFormNumberFormatter({int digits = 0, String? decimalSeparator, String? thousandSeparator, bool signed = false})

Properties

decimalSeparator String?
final
digits int
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
signed bool
final
thousandSeparator String?
final

Methods

decode(String? input) → T?
override
encode(T? value) String
override
formatEditUpdate(TextEditingValue oldValue, TextEditingValue newValue) TextEditingValue
Called when text is being typed or cut/copy/pasted in the EditableText.
override
getTextInputType() TextInputType
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited