DraftModeFormList<ItemType> class

Form-oriented list wrapper used by selection flows such as dropdown pickers.

Inheritance

Constructors

DraftModeFormList({Key? key, bool isPending = false, required List<ItemType> items, required DraftModeFormListItemBuilder<ItemType> itemBuilder, ItemType? selectedItem, Object? selectedKey, Object? itemKeyOf(ItemType item)?, ValueChanged<ItemType>? onTap, Widget? emptyPlaceholder, Widget? header, Widget? separator, Future<void> onRefresh()?, EdgeInsetsGeometry? padding, DraftModeUIListDismissible<ItemType>? dismissible})
const

Properties

dismissible DraftModeUIListDismissible<ItemType>?
final
emptyPlaceholder Widget?
final
hashCode int
The hash code for this object.
no setterinherited
final
isPending bool
final
itemBuilder DraftModeFormListItemBuilder<ItemType>
final
itemKeyOf Object? Function(ItemType item)?
final
items List<ItemType>
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onRefresh Future<void> Function()?
final
onTap ValueChanged<ItemType>?
final
padding EdgeInsetsGeometry?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedItem → ItemType?
final
selectedKey Object?
final
separator Widget?
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited