DraftModeUIPageNavigationBottom class
Platform-aware bottom navigation bar used by DraftModeUIPage.
Renders a three-slot row (leading / primary / trailing) with a top separator line derived from the theme.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- DraftModeUIPageNavigationBottom
Constructors
-
const
Properties
- backgroundColor → Color?
-
Override background colour for the bar.
final
- centerTitle → bool
-
Unused — kept for API symmetry with the top bar.
final
- containerHeight → double?
-
Minimum height constraint for the bar container.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
-
leading
→ List<
Widget> ? -
Widgets anchored to the left side of the bar.
final
- primary → Widget?
-
Primary widget centred in the bar.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
trailing
→ List<
Widget> ? -
Widgets anchored to the right side of the bar.
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited