bottomCenter property
Widget anchored to the center slot of the bottom bar.
Implementation
final DraftModeUIPageNavigationItemBottom? bottomCenter;
Widget anchored to the center slot of the bottom bar.
final DraftModeUIPageNavigationItemBottom? bottomCenter;