onSavePressed property

Future<bool> Function()? onSavePressed
final

Optional callback invoked when the save action is triggered; returning true pops the page with a positive result.

Implementation

final Future<bool> Function()? onSavePressed;