topLeadingText property
Optional label rendered next to the platform back icon when topLeading
is not provided. When null, the control renders icon-only.
Implementation
final String? topLeadingText;
Optional label rendered next to the platform back icon when topLeading
is not provided. When null, the control renders icon-only.
final String? topLeadingText;