DraftModeStorageEntity<T> class abstract

Strongly typed entity-oriented surface backed by encoded storage adapters.

Implementers

Constructors

DraftModeStorageEntity()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

deleteOne({String? key}) Future<bool>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
readAll({String? key, List<String>? nodeRoute}) Future<List<T>>
readOne({String? key}) Future<T?>
toString() String
A string representation of this object.
inherited
writeAll(List<T> value, {String? key}) Future<bool>
writeOne(T value, {String? key}) Future<bool>

Operators

operator ==(Object other) bool
The equality operator.
inherited