storage/secure_storage library

Classes

DraftModeSecureStorageDriver
Driver abstraction so secure storage can be mocked without platform channels in tests.
DraftModeStorageSecure
Secure implementation suited for secrets or tokens that require OS-level protection.