DraftModeAndroidFieldStyles class

Shared Android/Material field styling for framework-owned controls.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

boxDecoration(DraftModeUIThemeData theme, {Color? borderColor}) BoxDecoration
idleBorderColor(DraftModeUIThemeData theme) Color
labelTextStyle(DraftModeUIThemeData theme) TextStyle
outlineBorder(DraftModeUIThemeData theme, Color color, {double width = defaultBorderWidth}) OutlineInputBorder
valueTextStyle(DraftModeUIThemeData theme, {Color? color}) TextStyle
wrapLabeledField({required DraftModeUIThemeData theme, required Widget field, String? label, double? bottomSpacing}) Widget