DraftModeAdaptiveCardConfig class

Inheritance

Constructors

DraftModeAdaptiveCardConfig({required DraftModeUIThemeData theme, required IconData? icon, required String title, required String description, required Color? iconColor, required Color? titleColor, required Color? descriptionColor, required EdgeInsetsGeometry? effectiveOuterPadding, required EdgeInsetsGeometry? innerPadding, required double? borderRadius, required Color? backgroundColor, required Color? borderColor, required List<BoxShadow>? shadow, required VoidCallback? onTap})
const

Properties

backgroundColor Color?
finalinherited
borderColor Color?
finalinherited
borderRadius double?
finalinherited
description String
final
descriptionColor Color?
final
effectiveOuterPadding EdgeInsetsGeometry?
finalinherited
hashCode int
The hash code for this object.
no setterinherited
icon IconData?
final
iconColor Color?
final
innerPadding EdgeInsetsGeometry?
finalinherited
onTap VoidCallback?
finalinherited
resolvedBackgroundColor Color
no setterinherited
resolvedBorder Border?
no setterinherited
resolvedBorderRadius double
no setterinherited
resolvedDescriptionColor Color
no setter
resolvedIconColor Color
no setter
resolvedInnerPadding EdgeInsetsGeometry
no setterinherited
resolvedShadow List<BoxShadow>?
no setterinherited
resolvedTitleColor Color
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shadow List<BoxShadow>?
finalinherited
theme DraftModeUIThemeData
finalinherited
title String
final
titleColor Color?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited