DraftModeUIDialogConfig class

Constructors

DraftModeUIDialogConfig({required DraftModeUIThemeData theme, required String title, required String finalMessage, required String confirmLabel, required String cancelLabel, required bool showCancelButton, required bool isError, required VoidCallback onConfirm, required VoidCallback onCancel})
const

Properties

cancelLabel String
final
confirmLabel String
final
finalMessage String
final
hashCode int
The hash code for this object.
no setterinherited
isError bool
final
onCancel VoidCallback
final
onConfirm VoidCallback
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showCancelButton bool
final
theme DraftModeUIThemeData
final
title String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited