DraftModeAdaptiveSwitchConfig class final

Constructors

DraftModeAdaptiveSwitchConfig({required DraftModeUIThemeData theme, required bool value, required ValueChanged<bool>? onChanged})
const

Properties

androidActiveThumbColor Color
no setter
androidActiveTrackColor Color
no setter
androidInactiveThumbColor Color
no setter
androidInactiveTrackColor Color
no setter
androidThumbIcon WidgetStateProperty<Icon?>
no setter
androidTrackOutlineColor WidgetStateProperty<Color?>
no setter
hashCode int
The hash code for this object.
no setterinherited
onChanged ValueChanged<bool>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
theme DraftModeUIThemeData
final
value bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

androidHeight → const double
androidWidth → const double
cupertinoTrackInset → const double