autoPending property

bool autoPending
final

When true, the button automatically manages its own pending state.

On press the button enters the pending state, invokes onPressed, and if the callback returns a Future, awaits it. The pending state is cleared once the future completes (or immediately if the callback is synchronous). On error the pending state is cleared and the error is rethrown.

Implementation

final bool autoPending;