pendingChild property
Optional widget shown in place of child while the button is pending.
When null, a DraftModeUISpinner sized to match the button's text
color is used.
Implementation
final Widget? pendingChild;
Optional widget shown in place of child while the button is pending.
When null, a DraftModeUISpinner sized to match the button's text
color is used.
final Widget? pendingChild;