DraftModeUIDateTimeMinuteInterval enum

Minute granularity used by DraftModeUIDateTime.

Inheritance
Available extensions

Values

one → const DraftModeUIDateTimeMinuteInterval
const DraftModeUIDateTimeMinuteInterval(1)
five → const DraftModeUIDateTimeMinuteInterval
const DraftModeUIDateTimeMinuteInterval(5)
ten → const DraftModeUIDateTimeMinuteInterval
const DraftModeUIDateTimeMinuteInterval(10)
fifteen → const DraftModeUIDateTimeMinuteInterval
const DraftModeUIDateTimeMinuteInterval(15)
thirty → const DraftModeUIDateTimeMinuteInterval
const DraftModeUIDateTimeMinuteInterval(30)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
minutes int
Number of minutes between entries rendered in the picker.
final
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<DraftModeUIDateTimeMinuteInterval>
A constant List of the values in this enum, in order of their declaration.