DraftModeUIDateTimeStyles class
Shared visual tokens for the inline date/time UI components.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
dayTextStyle(
{required bool isSelected, required bool isToday}) → TextStyle -
monthLabelTextStyle(
{required bool expanded}) → TextStyle
Constants
- accentColor → const Color
- accentFillColor → const Color
- compactButtonPadding → const EdgeInsetsGeometry
- labelColor → const Color
- weekdayTextStyle → const TextStyle