autoConfirm property
When set, the dialog auto-confirms after this duration and displays a countdown in the message body.
Implementation
final Duration? autoConfirm;
When set, the dialog auto-confirms after this duration and displays a countdown in the message body.
final Duration? autoConfirm;