itemBuilder property
Builds the widget for a single item.
The second callback argument is true when the item matches
the configured selection semantics.
Implementation
final Widget Function(ItemType item, bool isSelected) itemBuilder;
Builds the widget for a single item.
The second callback argument is true when the item matches
the configured selection semantics.
final Widget Function(ItemType item, bool isSelected) itemBuilder;