itemKeyOf property
Maps an item to a stable logical key used for picker selection.
Implementation
final Object? Function(ItemType item)? itemKeyOf;
Maps an item to a stable logical key used for picker selection.
final Object? Function(ItemType item)? itemKeyOf;