DraftModeListItem<IdType, ValueType> class

Lightweight data record used by DraftModeUIList.

Each item stores a stable id used for keys plus the value object passed to DraftModeUIList.itemBuilder. Supply type arguments to gain compile-time safety; bare DraftModeListItem defaults to <dynamic, dynamic>.

Constructors

DraftModeListItem({required IdType id, required ValueType value})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
id → IdType
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value → ValueType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited