useFixedLabelWidth property
Whether the optional label should use the fixed section label width.
Defaults to true. Set to false for rows like switches where the label
should take natural width and the control can remain right-aligned.
Implementation
final bool useFixedLabelWidth;