transparent property
When true, grouped background decoration is suppressed so the section
blends with its parent.
Implementation
final bool transparent;
When true, grouped background decoration is suppressed so the section
blends with its parent.
final bool transparent;