ui/components/timeline library

Classes

DraftModeUITimelineButtons
Convenience access to timeline-specific icons.
DraftModeUITimelineInsertRow
Plus-style insert row that keeps the timeline visually connected.
DraftModeUITimelineRow
Reusable row layout that combines the timeline gutter with row content.
DraftModeUITimelineText
Text-first content block commonly used with DraftModeUITimelineRow.