DraftModeUIToastStyle enum

Colour scheme applied to a DraftModeUIToast.

Inheritance
Available extensions

Values

success → const DraftModeUIToastStyle

Green background — indicates a successful action.

warning → const DraftModeUIToastStyle

Orange background — indicates a warning.

error → const DraftModeUIToastStyle

Red background with white text — indicates an error.

notice → const DraftModeUIToastStyle

Neutral grey background — generic informational toast.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<DraftModeUIToastStyle>
A constant List of the values in this enum, in order of their declaration.