ColorRole class

Pairs a background colour with its matching foreground/text colour.

Constructors

ColorRole(Color background, Color text)
const

Properties

background Color
The surface/fill colour.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text Color
The foreground colour rendered on top of background.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

lerp(ColorRole? a, ColorRole? b, double t) ColorRole?
Linearly interpolates between two ColorRoles.