isAndroid property
bool
get
isAndroid
Whether this token set targets the Android visual style.
Implementation
bool get isAndroid => platformStyle.isAndroid;
Whether this token set targets the Android visual style.
bool get isAndroid => platformStyle.isAndroid;