DraftModePlatformStyle enum
Visual platform styles currently supported by DraftModeFramework.
- Inheritance
- Available extensions
Values
- ios → const DraftModePlatformStyle
-
Cupertino-first rendering and interaction patterns.
- android → const DraftModePlatformStyle
-
Material-oriented rendering and interaction patterns.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- isAndroid → bool
-
Available on DraftModePlatformStyle, provided by the DraftModePlatformStyleX extension
Whether this style resolves to the Android/Material presentation.no setter - isIOS → bool
-
Available on DraftModePlatformStyle, provided by the DraftModePlatformStyleX extension
Whether this style resolves to the iOS/Cupertino presentation.no setter - name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
DraftModePlatformStyle> - A constant List of the values in this enum, in order of their declaration.