core/validation_issue library
Classes
- DraftModeValidationAfter
- Raised when a value must be after a comparison date/time.
- DraftModeValidationAfterOrEqual
- Raised when a value must be after or equal to a comparison date/time.
- DraftModeValidationGreaterThan
- Raised when a value must be greater than a comparison value.
- DraftModeValidationIssue
- Structured validation issue that resolves to localized text in the UI layer while still remaining usable in non-UI workflows.
- DraftModeValidationMaxLength
- Raised when a string exceeds the allowed length.
- DraftModeValidationRequired
- Raised when a required value is missing.