DraftModeValidationRequired class
Raised when a required value is missing.
- Inheritance
-
- Object
- DraftModeValidationIssue
- DraftModeValidationRequired
Constructors
- DraftModeValidationRequired()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resolve(
BuildContext context) → String -
Resolves this issue into user-facing text for the given
context.override -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited