DraftModeFormStateI class abstract
- Implemented types
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
attribute<
T> (DraftModeFieldDefinition< T> definition) → DraftModeFormAttribute<T> -
beginAttributeValidation(
dynamic attribute) → void -
Marks the start of validation for a concrete
attribute.inherited -
endAttributeValidation(
dynamic attribute) → void -
Marks the end of validation for a concrete
attribute.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
read<
V> (dynamic attribute) → V? -
Returns the current value for a related
attribute, if available.inherited -
registerAttribute<
T> (DraftModeFormAttribute< T> attribute) → void -
registerDependency(
dynamic dependency) → void -
Records that the current validation depends on
dependency.inherited -
registerField<
T> (DraftModeFormAttribute< T> attribute, GlobalKey<FormFieldState< key) → voidT> > -
replaceAttribute<
T> (DraftModeFormAttribute< T> attribute, T? value) → void -
replaceValue<
T> (DraftModeFieldDefinition< T> definition, T? value) → void -
toString(
) → String -
A string representation of this object.
inherited
-
unregisterField<
T> (DraftModeFormAttribute< T> attribute, GlobalKey<FormFieldState< key) → voidT> > -
updateAttribute<
T> (DraftModeFormAttribute< T> attribute, T? value) → void -
updateValue<
T> (DraftModeFieldDefinition< T> definition, T? value) → void -
validateAttribute<
T> (DraftModeFormAttribute< T> attribute) → void -
value<
T> (DraftModeFieldDefinition< T> definition) → T?
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited