DraftModeFormFormatter<T> class
abstract
Shared formatter interface used by DraftMode form fields.
- Inheritance
-
- Object
- TextInputFormatter
- DraftModeFormFormatter
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
decode(
String? input) → T? -
encode(
T? value) → String -
formatEditUpdate(
TextEditingValue oldValue, TextEditingValue newValue) → TextEditingValue -
Called when text is being typed or cut/copy/pasted in the EditableText.
inherited
-
getTextInputType(
) → TextInputType -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited