DraftModeStorageEntityHttp<T> class
HTTP-backed typed entity manager.
- Implemented types
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
close(
) → void - Closes the owned HTTP client when the storage adapter created it.
-
deleteOne(
{String? key}) → Future< bool> -
override
-
deleteOneHttp(
{String? key, Map< String, dynamic> ? queryParameters}) → Future<bool> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
readAll(
{String? key, List< String> ? nodeRoute}) → Future<List< T> > -
override
-
readAllHttp(
{String? key, List< String> ? nodeRoute, Map<String, dynamic> ? queryParameters}) → Future<List< T> > -
readOne(
{String? key, Map< String, dynamic> ? queryParameters}) → Future<T?> -
override
-
toString(
) → String -
A string representation of this object.
inherited
-
writeAll(
List< T> value, {String? key}) → Future<bool> -
override
-
writeAllHttp(
List< T> value, {String? key, String? method, Map<String, dynamic> ? queryParameters}) → Future<bool> -
writeOne(
T value, {String? key}) → Future< bool> -
override
-
writeOneHttp(
T value, {String? key, String? method, Map< String, dynamic> ? queryParameters}) → Future<bool>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited