DraftModeStorageEntityManager<T> class
Typed entity manager that maps encoded payloads to domain objects.
This manager keeps serialization, storage access, and optional schema validation together for one entity type while remaining UI-agnostic.
- Implemented types
- Implementers
Constructors
-
DraftModeStorageEntityManager(Type type, {DraftModeStorage<
String> ? storage, required T fromJson(Map<String, dynamic> ), required Map<String, dynamic> toJson(T), DraftModeEntitySchema<T> ? schema, String? storageKey})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
buildStorage(
) → DraftModeStorage< String> - Override to provide a default storage adapter when one is not injected.
-
deleteOne(
{String? key}) → Future< bool> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
readAll(
{String? key, List< String> ? nodeRoute}) → Future<List< T> > -
override
-
readOne(
{String? key}) → Future< T?> -
override
-
toString(
) → String -
A string representation of this object.
inherited
-
writeAll(
List< T> value, {String? key}) → Future<bool> -
override
-
writeOne(
T value, {String? key}) → Future< bool> -
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited