DraftModeStorageEntitySecure<T> class
Secure-storage-backed typed entity manager.
- Inheritance
-
- Object
- DraftModeStorageEntityManager<
T> - DraftModeStorageEntitySecure
Constructors
-
DraftModeStorageEntitySecure(Type type, {required T fromJson(Map<
String, dynamic> ), required Map<String, dynamic> toJson(T), DraftModeEntitySchema<T> ? schema, String? storageKey, DraftModeSecureStorageDriver? driver})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
buildStorage(
) → DraftModeStorageSecure -
Override to provide a default storage adapter when one is not injected.
override
-
deleteOne(
{String? key}) → Future< bool> -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
readAll(
{String? key, List< String> ? nodeRoute}) → Future<List< T> > -
inherited
-
readOne(
{String? key}) → Future< T?> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
writeAll(
List< T> value, {String? key}) → Future<bool> -
inherited
-
writeOne(
T value, {String? key}) → Future< bool> -
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited