DraftModeStorageHttp class
Thin adapter around http.Client for repositories that read/write encoded
payloads against REST endpoints.
- Implemented types
Constructors
-
DraftModeStorageHttp({required String baseUrl, Client? client, Map<
String, String> ? headers})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
close(
) → void -
Closes the underlying
http.Clientwhen this instance created it. -
delete(
{String? key}) → Future< bool> -
override
-
deletePath(
{String? path, Map< String, dynamic> ? queryParameters}) → Future<bool> - Deletes a resource on an HTTP path below the configured base URL.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
read(
{String? key}) → Future< String?> -
override
-
readPath(
{String? path, Map< String, dynamic> ? queryParameters}) → Future<String?> - Reads an encoded payload from an HTTP path below the configured base URL.
-
toString(
) → String -
A string representation of this object.
inherited
-
write(
String value, {String? key}) → Future< bool> -
override
-
writePath(
String value, {String? path, String? method, Map< String, dynamic> ? queryParameters}) → Future<bool> - Writes an encoded payload to an HTTP path using POST, PUT, or PATCH.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited