DraftModeStorageShared class
DraftModeStorage backed by SharedPreferences, primarily for lightweight
non-sensitive data persisted on device.
- Implemented types
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
delete(
{String? key}) → Future< bool> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
read(
{String? key}) → Future< String?> -
override
-
toString(
) → String -
A string representation of this object.
inherited
-
write(
String value, {String? key}) → Future< bool> -
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited