DraftModeUIDateTimeValue class
Shared normalization and formatting helpers used by adaptive date/time UI.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
canonicalAndroidPanel(
DraftModeUIDateTimePanel panel) → DraftModeUIDateTimePanel -
daysInMonth(
int year, int month) → int -
formatDate(
BuildContext context, DateTime value, {required DraftModePlatformStyle style}) → String -
formatTime(
BuildContext context, DateTime value, {required DraftModePlatformStyle style}) → String -
isSameDate(
DateTime a, DateTime b) → bool -
mergeDate(
DateTime original, DateTime selectedDate) → DateTime -
mergeTime(
DateTime original, int hour, int minute) → DateTime -
normalize(
DateTime value, {required DraftModeUIDateTimeMode mode, required DraftModeUIDateTimeMinuteInterval minuteInterval}) → DateTime -
weekdayLabels(
String locale) → List< String> -
yearOptions(
) → List< int>