selectedItem property
ItemType?
selectedItem
final
The currently selected item, matched by identity by default.
When itemKeyOf is provided, the list first tries identity and then falls back to comparing selection keys derived from selectedItem or selectedKey.
Implementation
final ItemType? selectedItem;