selectedKey property
Stable selection key used together with itemKeyOf.
This is useful when the selected value is stored separately from the current item instances, such as IDs returned from a repository or form field values.
Implementation
final Object? selectedKey;