DraftModeAdaptiveSectionConfig class
Constructors
-
DraftModeAdaptiveSectionConfig({required DraftModeUIThemeData theme, required String? header, required List<
Widget> children, required bool transparent}) -
const
Properties
-
children
→ List<
Widget> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasHeader → bool
-
no setter
- header → String?
-
final
- headerText → String
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- theme → DraftModeUIThemeData
-
final
- transparent → bool
-
final
- uppercaseHeaderText → String
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited